"use client";
import clsx from "clsx";
import { ChangeEvent, useEffect, useState } from "react";
import { useFormState } from "react-dom";
import { Input } from "~/components/ui/input";
import {
  Select,
  SelectContent,
  SelectItem,
  SelectTrigger,
  SelectValue,
} from "~/components/ui/select";
import { addSubRegion } from "~/server/actions/addSubRegion";
import SubmitButton from "../SubmitButton";

type Region = {
  id: string;
  name: string;
  countryId: string;
};
type Country = {
  id: string;
  name: string;
};

export default function CreateSubRegionForm(props: {
  allRegions: Region[];
  allCountries: Country[];
}) {
  const { allRegions, allCountries } = props;
  const [selectCountryId, setSelectCountryId] = useState<string | undefined>(
    undefined,
  );
  const [selectCountryRegions, setSelectCountryRegions] = useState<Region[]>(
    [],
  );
  const [formState, formActions] = useFormState(addSubRegion, {
    message: "",
    errors: undefined,
    fieldValues: {
      name: "",
      regionId: "",
    },
  });

  useEffect(() => {
    if (selectCountryId) {
      const regions = allRegions.filter(
        (region) => region.countryId === selectCountryId,
      );
      setSelectCountryRegions(regions);
    }
  }, [selectCountryId]);
  return (
    <div>
      {/* country selector */}
      <p>{selectCountryId}</p>
      <Select
        name="country"
        onValueChange={(value) => setSelectCountryId(value)}
      >
        <SelectTrigger className={`w-[180px] `}>
          <SelectValue placeholder="Country" />
        </SelectTrigger>
        <SelectContent>
          {allCountries.map((country) => (
            <SelectItem key={country.id} value={country.id}>
              {country.name}
            </SelectItem>
          ))}
        </SelectContent>
      </Select>
      <form action={formActions}>
        {/* region selector */}
        <Select name="regionId">
          <SelectTrigger
            className={`w-[180px] ${clsx({ "border-red-500": formState.errors?.regionId })}`}
          >
            <SelectValue placeholder="Region" />
          </SelectTrigger>
          <SelectContent>
            {selectCountryRegions.map((region) => (
              <SelectItem key={region.id} value={region.id}>
                {region.name}
              </SelectItem>
            ))}
          </SelectContent>
        </Select>
        <Input
          name="name"
          id="name"
          placeholder="Name"
          className={`${clsx({ "border-red-500": formState.errors?.name })}`}
        />
        <SubmitButton text={"sub region"} />
      </form>
    </div>
  );
}
